Directive

Enum Directive 

#[non_exhaustive]
pub enum Directive { Emit { event: AgentEvent, }, SpawnAgent { name: String, config: Value, }, StopChild { name: String, }, Schedule { action: String, delay: Duration, }, RunInstruction { instruction: String, input: Value, }, Cron { expression: String, action: String, }, Stop { reason: Option<String>, }, SpawnTask { description: String, input: Value, }, StopTask { task_id: String, }, Custom { payload: Box<dyn DirectivePayload>, }, }
Directive - typed effect description returned by agent nodes.

Directives describe side effects without executing them, enabling pure unit testing.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Emit

Emit an event to the event stream.

Fields

event: AgentEvent

Event to emit.



SpawnAgent

Request spawning a child agent.

Fields

name: String

Agent name.

config: Value

Agent configuration.



StopChild

Request stopping a child agent.

Fields

name: String

Child agent name.



Schedule

Schedule a delayed action.

Fields

action: String

Action to schedule.

delay: Duration

Delay duration.



RunInstruction

Request runtime to execute instruction and route result back.

Fields

instruction: String

Instruction text.

input: Value

Input data.



Cron

Schedule recurring action.

Fields

expression: String

Cron expression.

action: String

Action to execute.



Stop

Request agent stop.

Fields

reason: Option<String>

Optional reason.



SpawnTask

Spawn a background task.

Fields

description: String

Task description.

input: Value

Task input data.



StopTask

Cancel a background task.

Fields

task_id: String

Task ID to stop.



Custom

User-defined directive (requires typetag registration).

Fields

payload: Box<dyn DirectivePayload>

Custom directive payload.