DirectiveResult

Struct DirectiveResult 

pub struct DirectiveResult<S: State> {
    pub state: S,
    pub directives: Vec<Directive>,
}
Result combining state update and zero or more directives.

Agent nodes return this to indicate both immediate state changes and deferred effects to be executed by the runtime.

Fields

state: S

Updated state (applied immediately).

directives: Vec<Directive>

Deferred effect descriptions (executed by runtime).

Implementations

Source

impl<S: State> DirectiveResult<S>

pub const fn state_only(state: S) -> Self

Create a result with only state, no directives.

pub fn with_directive(state: S, directive: Directive) -> Self

Create a result with state and a single directive.

pub const fn with_directives(state: S, directives: Vec<Directive>) -> Self

Create a result with state and multiple directives.