#[non_exhaustive]pub struct NetworkConfig {
pub enabled: bool,
pub allowed_domains: Option<Vec<String>>,
pub denied_domains: Vec<String>,
pub allow_trusted_domains: bool,
}Expand description
Network access rules.
Disabled by default — coding agents should explicitly opt-in to the domains they require.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.enabled: boolEnable outbound network access. Default: false.
allowed_domains: Option<Vec<String>>Domain allowlist. Supports wildcards: "*.npmjs.org".
None means all domains are permitted when enabled = true.
denied_domains: Vec<String>Domains that are always blocked, regardless of allowed_domains.
allow_trusted_domains: boolAlso allow domains from a system or user trusted-domains list (e.g. a corporate proxy allowlist).