SpanGuard

Struct SpanGuard 

pub struct SpanGuard<B: TracingBridge + 'static> { /* private fields */ }
RAII guard that ends a span when dropped.

If not explicitly completed via SpanGuard::complete, the span is ended with an error outcome on drop.

Implementations

Source

impl<B: TracingBridge + 'static> SpanGuard<B>

pub const fn new(bridge: Arc<B>, span_id: Uuid) -> Self

Creates a new span guard.

pub const fn span_id(&self) -> Uuid

Returns the span identifier.

pub async fn complete( self, outcome: SpanOutcome, attributes: &HashMap<String, Value>, )

Completes the span with the given outcome.

After calling this method, the drop implementation will not end the span again.