JsonOutputParser

Struct JsonOutputParser 

pub struct JsonOutputParser;
Parser that deserialises JSON text to serde_json::Value.

Useful when you need structured data from a model but do not have a specific Rust type to deserialise into.

Examples

use synwire_core::output_parsers::{OutputParser, JsonOutputParser};

let parser = JsonOutputParser;
let result = parser.parse(r#"{"key": "value"}"#).unwrap();
assert_eq!(result["key"], "value");