Virtual filesystem abstraction for agent data operations.
Provides a filesystem-like interface over heterogeneous data sources, allowing LLMs to interact with any data source using familiar operations (ls, read, write, cd, cp, mv, etc.).
Operations mirror Linux coreutils with their most useful arguments
abstracted into option structs. Providers declare which operations
they support via VfsCapabilities.
Re-exports
pub use error::VfsError;pub use grep_options::GrepOptions;pub use grep_options::GrepOutputMode;pub use memory::MemoryProvider;pub use output::OutputFormat;pub use output::format_output;pub use protocol::Vfs;pub use tools::vfs_tools;pub use types::CommunityEntry;pub use types::CommunityMembersResult;pub use types::CommunitySearchOptions;pub use types::CommunitySearchResult;pub use types::CommunitySummaryResult;pub use types::CpOptions;pub use types::DiffOptions;pub use types::DiffResult;pub use types::DirEntry;pub use types::DiskUsage;pub use types::DuOptions;pub use types::EditResult;pub use types::FileContent;pub use types::FileInfo;pub use types::FindEntry;pub use types::FindOptions;pub use types::GlobEntry;pub use types::GrepMatch;pub use types::HeadTailOptions;pub use types::HybridSearchOptions;pub use types::HybridSearchResult;pub use types::IndexEvent;pub use types::IndexHandle;pub use types::IndexOptions;pub use types::IndexResult;pub use types::IndexStatus;pub use types::LsOptions;pub use types::MkdirOptions;pub use types::MountInfo;pub use types::ReadRange;pub use types::RmOptions;pub use types::SemanticSearchOptions;pub use types::SemanticSearchResult;pub use types::SortField;pub use types::TransferResult;pub use types::TreeEntry;pub use types::TreeOptions;pub use types::VfsCapabilities;pub use types::WordCount;pub use types::WriteResult;
Modules
- agentic_
ignore - Agentic ignore file discovery and matching.
- error
- VFS error types.
- grep_
options - Grep options and result types.
- memory
- Ephemeral in-memory VFS provider implementation.
- output
- Output serialization for VFS responses.
- protocol
- Virtual filesystem trait.
- tools
- Pre-built tools that expose VFS operations to LLMs.
- types
- VFS response, capability, and option types.